Kepler class

Constructors

Kepler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

sha3digest → SHA3Digest
final

Static Methods

btcAddress(ECPublicKey pubkey) → String
return a BTC Address
byteSecret(String privateString, String publicString) → List<List<int>>
return a Bytes data secret
ethAddress(ECPublicKey pubkey) → String
return a ETH Address
generateKeyPair({Uint8List? seed}) → AsymmetricKeyPair<PublicKey, PrivateKey>
Generate Keypair
leftPadding(String s, int width) → String
loadPrivateKey(String storedkey) → ECPrivateKey
return a privateKey from hex string
loadPublicKey(String storedkey) → ECPublicKey
return a publicKey from hex string
privateDecrypt(String privateString, String publicString, String b64encoded, [String b64IV = ""]) → String
Decrypt data using self private key
privateDecryptRaw(String privateString, String publicString, Uint8List encdData, [String b64IV = ""]) → Uint8List
privateSign(String strPrivateKey, String message) → String
pubkeyEncrypt(String privateString, String publicString, String message) → Map<String, String>
Encrypt data using target public key
pubkeyEncryptRaw(String privateString, String publicString, Uint8List data) → Map<String, dynamic>
publicVerify(String strPublicKey, String message, String strSignature) → bool
rawSecret(String privateString, String publicString) → ECPoint
return a ECPoint data secret
strinifyPrivateKey(ECPrivateKey privateKey) → String
return a hex string version privateKey
strinifyPublicKey(ECPublicKey publicKey) → String
return a hex string version publicKey